@@ -16,9 +16,9 @@
   <a href="<?cs var:html_escape(ZerominScript) ?>?class=bbs&amp;method=load_index&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">インデックス</a>
   &gt;
 <?cs /if ?>
-  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ログ</a>
+  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(Date) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">ログ</a>
   &gt;
-  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">エラーログ閲覧</a>
+  <a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(Date) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">エラーログ閲覧</a>
 </div>
 
 <h1>エラーログ閲覧</h1>
@@ -30,9 +30,7 @@
 <?cs /if ?>
 
 <script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/jquery/datePicker.js" charset="UTF-8"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domLib.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/domTT/domTT.js?v=<?cs var:html_escape(SecuredVersion) ?>"></script>
-<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js?v=<?cs var:html_escape(SecuredVersion) ?>" charset="UTF-8"></script>
+<script type="text/javascript" src="<?cs var:html_escape(StaticURI) ?>/js/zeromin2/lookup.js" charset="UTF-8"></script>
 <script type="text/javascript" charset="UTF-8">
 //<![CDATA[
 jQuery(function(){
@@ -50,7 +48,7 @@ Zeromin2.addStyleSheet("<?cs var:html_escape(StaticURI) ?>/css/domTT.css");
 });
 function lookup( ip, element, event ) {
     Zeromin2.lookup(
-        jQuery("form#logErrorContainerForm").get(0), ip, element, event );
+        jQuery("#logErrorContainerForm").get(0), ip, element, event );
 }
 //]]>
 </script>
@@ -75,11 +73,11 @@ function lookup( ip, element, event ) {
 <input type="submit" value="表示" /><br />
 (&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
 <span class="page">
-<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
+<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(CurrentDate) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
 <?cs each:item = Pages ?>
-<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
+<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(CurrentDate) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
 <?cs /each ?>
-<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
+<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_error&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(CurrentDate) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
 </span>
 </p>
 
@@ -89,7 +87,10 @@ function lookup( ip, element, event ) {
     <th>エラー内容</th>
     <th>IPアドレス</th>
     <th>時刻</th>
+    <?cs if:BBS ?>
     <th>スレッド名</th>
+    <th>&nbsp;</th>
+    <?cs /if ?>
   </tr>
   </thead>
   <tbody>
@@ -97,8 +98,11 @@ function lookup( ip, element, event ) {
   <tr>
     <td><?cs var:html_escape(item.error) ?></td>
     <td><a href="javascript:void(0)" onclick="lookup( '<?cs var:html_escape(item.ip) ?>', this, event )"><?cs var:html_escape(item.ip) ?></a></td>
-    <td><?cs var:html_escape(item.date) ?></td>
-    <td><?cs var:html_escape(item.key) ?></td>
+    <td><?cs var:item.date ?></td>
+    <?cs if:BBS ?>
+    <td><?cs var:html_escape(item.subject) ?></td>
+    <td><a href="<?cs var:html_escape(ZerominScript) ?>?class=thread&amp;method=lookup&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;target=<?cs var:html_escape(item.ip) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>" onclick="Zeromin2.redirect(this);return false">[HL]</a></td>
+    <?cs /if ?>
   </tr>
   <?cs /each ?>
   </tbody>
