@@ -52,11 +52,11 @@ function lookup( ip, element, event ) {
 <input type="text" name="item" size="5" value="<?cs var:html_escape(Item) ?>" /><br />
 (&nbsp;<?cs var:html_escape(Total) ?>件&nbsp;-&nbsp;現在<?cs var:html_escape(Current) ?>ページ目&nbsp;)<br />
 <span class="page">
-<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_host&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
+<?cs if:Prev ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_host&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(CurrentDate) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Prev) ?>" onclick="Zeromin2.redirect(this);return false">&lt;&lt;&nbsp;前</a><?cs /if ?>
 <?cs each:item = Pages ?>
-<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_host&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
+<a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_host&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(CurrentDate) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(item.num) ?>" onclick="Zeromin2.redirect(this);return false"><?cs var:html_escape(item.num) ?></a>
 <?cs /each ?>
-<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_host&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
+<?cs if:Next ?><a href="<?cs var:html_escape(ZerominScript) ?>?class=log&amp;method=load_host&amp;bbs=<?cs var:html_escape(BBS) ?>&amp;by=<?cs var:html_escape(By) ?>&amp;date=<?cs var:html_escape(CurrentDate) ?>&amp;<?cs var:html_escape(SessionName) ?>=<?cs var:html_escape(Session) ?>&amp;item=<?cs var:html_escape(Item) ?>&amp;offset=<?cs var:html_escape(Next) ?>" onclick="Zeromin2.redirect(this);return false">次&nbsp;&gt;&gt;</a><?cs /if ?>
 </span>
 </p>
 
