@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Note.pm 1827 2009-04-08 15:24:43Z hikarin $
+# $Id: Note.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Img0ch::App::Note;
@@ -46,7 +46,8 @@ sub run {
                 'note_error', 'shiftjis',
                 sub { ${ $_[0] } =~ s/<br>/\n/gxms; ${ $_[0] } }
             );
-            $iApp->init()         or return $iApp->redirect_error(@args);
+            $iApp->init() or return $iApp->redirect_error(@args);
+            $iApp->convert_params_if_not_utf8();
             $iApp->get_host()     or return $iApp->redirect_error(@args);
             $iApp->validate()     or return $iApp->redirect_error(@args);
             $iApp->is_writeable() or return $iApp->redirect_error(@args);
@@ -542,6 +543,15 @@ sub update_note {
     return;
 }
 
+sub convert_params_if_not_utf8 {
+    my ($iApp)   = @_;
+    my $iBBS     = $iApp->bbs();
+    my $encoding = $iBBS->get_encoding();
+    $encoding ne 'utf8'
+        and $iApp->{_request}
+        ->convert_params_by_charset( $iApp->kernel(), $encoding );
+}
+
 sub get_applet_type { $_[0]->{__applet_magic} }
 
 sub get_draft_repository { $_[0]->{__draft} }
@@ -659,5 +669,14 @@ sub set_image_to_file_internal {
     return;
 }
 
+sub convert_params_by_charset {
+    my ( $iRequest, $iKernel, $charset ) = @_;
+    my $new_params = {};
+    while ( my ( $k, $v ) = each %{ $iRequest->{__param} } ) {
+        $new_params->{$k} = $iKernel->get_encoded_str( $v, $charset, 'utf8' );
+    }
+    $iRequest->{__param} = $new_params;
+}
+
 1;
 __END__
