@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2008 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: UFM.pm 1645 2008-02-06 15:40:18Z hikarin $
+# $Id: UFM.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Img0ch::App::UFM;
@@ -31,8 +31,10 @@ sub new {
     bless {
         __bbs     => undef,
         __config  => $iKernel->get_config(),
+        __filter  => undef,
         __kernel  => $iKernel,
         __key     => 0,
+        __param   => {},
         __resno   => 0,
         __request => Img0ch::Request->new(@args),
         __setting => undef,
@@ -57,8 +59,11 @@ sub run {
 
     $result or return $iApp->redirect_error('remove');
     my $iRequest = $iApp->{__request};
-    $iRequest->send_http_header( $ctype || 'text/html' );
-    $iTemplate ? $iTemplate->flush() : $iRequest->print($body);
+    my $cs = $iApp->{__bbs} ? $iApp->{__bbs}->get_encoding() : undef;
+    $iRequest->send_http_header( $ctype || 'text/html', $cs );
+    $iTemplate
+        ? $iTemplate->flush( $iApp->{__filter} )
+        : $iRequest->print( $body, $iApp->{__filter} );
     return 1;
 }
 
@@ -78,6 +83,10 @@ sub init {
         $key = $1 eq '0000000000' ? $key : $1;
         ( $path[3] || '0' ) =~ /(\d+)/xms;
         $resno = $1 || $resno;
+        if ( scalar @path > 5 ) {
+            splice @path, 0, 4, ();
+            %{ $iApp->{__param} } = @path;
+        }
     }
 
     my $iBBS = Img0ch::BBS->new( $iApp->{__kernel}, { bbs => $bbs, } );
@@ -94,6 +103,19 @@ sub init {
     return 1;
 }
 
+sub get_param {
+    my ( $iApp, $key ) = @_;
+    my $value = $iApp->{__param}->{$key} || '';
+    $value =~ tr/+/ /;
+    $value =~ s/%([0-9A-Fa-f][0-9A-Fa-f])/pack('H2', $1)/egxms;
+    return Img0ch::Kernel::escape_html_entities($value);
+}
+
+sub get_param_int {
+    my ( $iApp, $key ) = @_;
+    return Img0ch::Kernel::intval( $iApp->{__param}->{$key} || '' );
+}
+
 sub process {
     my ( $iApp, $key, $resno ) = @_;
     my $iBBS     = $iApp->{__bbs};
@@ -101,8 +123,8 @@ sub process {
     my $iUpload  = $iApp->{__upload} = $iBBS->get_upload_instance($key);
     $iUpload->get($resno)->[0] or return ( 0, undef, '', \'' );
 
-    my $pass    = $iRequest->param('pass');
-    my $type    = $iRequest->param('type');
+    my $pass = $iApp->get_param('pass') || $iRequest->param('pass');
+    my $type = $iApp->get_param('type') || $iRequest->param('type');
     my $process = {};
 
     if ($pass) {
@@ -121,22 +143,117 @@ sub process {
             my $iKernel = $iApp->{__kernel};
             my ($ext)   = @{ $iUpload->get($resno) };
             my $path    = $iUpload->path( $resno, $ext );
+            my $size    = -s $path;
+            my $agent   = $iRequest->agent();
 
-            my $fh = $iKernel->get_read_file_handle($path);
-            binmode $fh;
-            my $buffer = do { local $/ = undef; <$fh> };
-            close $fh or $iKernel->throw_io_exception($path);
+            if ( $agent == 3 ) {
+                my $email = $iRequest->param('email');
+                my $id    = $iRequest->get_device_id($agent);
 
-            $iRequest->set_header( 'content-disposition',
-                'attachment; filename="' . "${resno}.${ext}" . '"' );
-            $iRequest->set_header( 'content-length', length($buffer) );
+                if ( $id and $email and $email =~ /ezweb\.ne\.jp\z/xms ) {
 
-            return ( 1, undef, 'application/octet-stream', \$buffer, );
+                    open my $fh, '<', $path
+                        or $iKernel->throw_io_exception($path);
+                    my $body = do { local $/ = undef; <$fh> };
+                    close $fh or $iKernel->throw_io_exception($path);
+
+                    my $iConfig = $iKernel->get_config();
+                    my $from    = $iConfig->get('MailRawAddress');
+
+                    my $message =~ s{<br\s?/?>}{\n}gxms;
+                    my $message_jis
+                        = $iKernel->get_encoded_str( $message, 'jis' );
+
+                    defined $Email::Send::VERSION
+                        or require Email::Send;
+
+                    my $sender;
+                    if ( my $sendmail = $iConfig->get('SendmailPath') ) {
+                        $sender
+                            = Email::Send->new( { mailer => 'Sendmail' } );
+                        $Email::Send::Sendmail::SENDMAIL = $sendmail;
+                    }
+                    elsif ( my $qmail = $iConfig->get('QmailPath') ) {
+                        $sender = Email::Send->new( { mailer => 'Qmail' } );
+                        $Email::Send::Qmail::QMAIL = $qmail;
+                    }
+                    else {
+                        my $host = $iConfig->get('smtp.host');
+                        my $port = $iConfig->get_int('smtp.port');
+                        $port and $host = join ':', $host, $port;
+                        $sender = Email::Send->new( { mailer => 'SMTP' } );
+                        $sender->mailer_args(
+                            [   Host => $host,
+                                ssl  => $iConfig->get('smtp.ssl'),
+                                tls  => $iConfig->get('smtp.tls'),
+                            ]
+                        );
+                    }
+
+                    defined $Email::MIME::Creator::VERSION
+                        or require Email::MIME::Creator;
+                    defined &{'Img0ch::Util::Ezweb::ext2type'}
+                        or require Img0ch::Util::Ezweb;
+
+                    my $filename   = $key . '-' . $resno . '.' . $ext;
+                    my $mail_parts = [
+                        Email::MIME->create(
+                            attributes => {
+                                filename => $filename,
+                                content_type =>
+                                    Img0ch::Util::Ezweb::ext2mime($ext),
+                                encoding => 'base64',
+                                name     => $filename,
+                            },
+                            body => $body,
+                        )
+                    ];
+                    my $mail_body = Email::MIME->create(
+                        header => [
+                            From    => $from,
+                            To      => $email,
+                            Subject => $filename
+                        ],
+                        parts => $mail_parts,
+                    );
+
+                    my $result = $sender->send( $mail_body->as_string() );
+                    $process->{address_is_invalid} = 0;
+                    if ($result) {
+                        $process->{send_ok}     = 1;
+                        $process->{send_errstr} = '';
+                    }
+                    else {
+                        $process->{send_ok}     = 0;
+                        $process->{send_errstr} = $result;
+                    }
+                }
+                else {
+                    $process->{send_ok}            = 0;
+                    $process->{address_is_invalid} = 1;
+                }
+            }
+            else {
+                my $fh = $iKernel->get_read_file_handle($path);
+
+                binmode $fh;
+                my $buffer = do { local $/ = undef; <$fh> };
+                close $fh or $iKernel->throw_io_exception($path);
+
+                $iRequest->enable_binary();
+                $iRequest->set_header( 'content-disposition',
+                    'attachment; filename="' . "${resno}.${ext}" . '"' );
+                $iRequest->set_header( 'content-length', $size );
+
+                require MIME::Types;
+                return ( 1, undef, MIME::Types->new()->mimeTypeOf($ext),
+                    \$buffer, );
+            }
         }
         elsif ( $type eq 'confirm' ) {
-            $js->{remove}   = $iUpload->can_remove( $resno,   $pass );
+            $js->{remove} = $iUpload->can_remove( $resno, $pass );
             $js->{download} = $iUpload->can_download( $resno, $pass );
-            $process->{ok}  = 1;
+            $process->{ok} = 1;
         }
         if ( $iRequest->param('js') ) {
             return ( ( $process->{ok} || $process->{removed} || 0 ),
@@ -238,8 +355,8 @@ sub load_poll {
 
     defined &{'Img0ch::Upload::Poll::new'} or require Img0ch::Upload::Poll;
     my $iUPoll = Img0ch::Upload::Poll->new( $iApp->{__bbs}, $key );
-    my $ret    = $iUPoll->get( $resno,                      $TAG );
-    my $i      = 1;
+    my $ret = $iUPoll->get( $resno, $TAG );
+    my $i = 1;
     for my $one (@$ret) {
         my @d = localtime( $one->{polled} );
         $d[5] += 1900;
@@ -266,8 +383,8 @@ sub load_review {
 
     defined &{'Img0ch::Upload::Poll::new'} or require Img0ch::Upload::Poll;
     my $iUPoll = Img0ch::Upload::Poll->new( $iApp->{__bbs}, $key );
-    my $ret    = $iUPoll->get( $resno,                      'STAR' );
-    my $i      = 1;
+    my $ret = $iUPoll->get( $resno, 'STAR' );
+    my $i = 1;
     for my $one (@$ret) {
         my ( $rate, $comment ) = split "\n", $one->{comment};
         my @d = localtime( $one->{polled} );
@@ -372,9 +489,15 @@ sub render {
         $i++;
     }
 
+    my $template_file = 'ufm';
+    if ( $iRequest->param('m') ) {
+        $template_file = 'ufm_mobile';
+        $iApp->{__filter} = sub { ${ $_[0] } =~ tr/\n//d; ${ $_[0] } };
+    }
+
     my $iMeta     = $iBBS->get_metadata_instance();
     my $iTemplate = $iBBS->get_template_instance(
-        {   file    => 'ufm',
+        {   file    => $template_file,
             request => $iRequest,
             setting => $iApp->{__setting},
         }
@@ -394,10 +517,10 @@ sub render {
     my $poll_bad  = {};
     if ( $key_param and $resno_param ) {
         %$poll_rate = %{ $iApp->load_review( $key_param, $resno_param ) };
-        %$poll_bad  = %{ $iApp->load_poll( $key_param,   $resno_param ) };
+        %$poll_bad = %{ $iApp->load_poll( $key_param, $resno_param ) };
     }
 
-    defined $HTML::TagClound::VERSION     or require HTML::TagCloud;
+    defined $HTML::TagClound::VERSION or require HTML::TagCloud;
     defined &{'Img0ch::Upload::Tag::new'} or require Img0ch::Upload::Tag;
     my $my_tags_stack   = [];
     my $tag_cloud_stack = [];
@@ -427,16 +550,20 @@ sub render {
     }
 
     $iTemplate->param(
-        {   Banner          => $iMeta->main_banner(),
-            DisplayPolledIP => ( $iConfig->get('ufm.no_polled_ip') ? 0 : 1 ),
-            Freezed         => $process->{freezed},
-            KEY             => $key_param,
-            META            => $iMeta->meta(),
+        {   AddressIsInvalid => $process->{address_is_invalid},
+            Banner           => $iMeta->main_banner(),
+            DisplayPolledIP  => ( $iConfig->get('ufm.no_polled_ip') ? 0 : 1 ),
+            Freezed          => $process->{freezed},
+            KEY              => $key_param,
+            META             => $iMeta->meta(),
             MyTags   => join( ' ', sort @$my_tags_stack ),
             Password => $pass_param,
             Removed  => $removed,
-            Failed => ( $pass_param and !$removed ),
-            Resno => $resno_param,
+            Failed =>
+                ( $pass_param and !exists $process->{send_ok} and !$removed ),
+            Resno         => $resno_param,
+            SendOK        => $process->{send_ok},
+            SendErrstr    => $process->{send_errstr},
             TagCloud      => $tag_cloud_stack,
             TagCloudHTML  => $cloud->html($max),
             TagCloudCSS   => $cloud->css(),
