@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Error.pm 1826 2009-04-08 15:23:25Z hikarin $
+# $Id: Error.pm 1985 2010-01-31 15:07:53Z hikarin $
 #
 
 package Img0ch::Error;
@@ -100,7 +100,7 @@ sub add {
     my ($iError) = @_;
     my $cache = $iError->{__cache};
     my %stop_to_add = map { ( $_ => 1 ) }
-        qw(DENY_POSTING_ASCII_ONLY INVALID_POST POST_WITH_NGWORD TOO_LONG_MESSAGE);
+        qw(DENY_POSTING_ASCII_ONLY INVALID_POST POST_WITH_NGWORD TOO_LONG_MESSAGE TOO_LONG_LINE);
 
     if (    $cache
         and !exists $stop_to_add{$cache}
