@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: DNSBL.pm 1339 2007-10-07 12:16:10Z hikarin $
+# $Id: DNSBL.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Img0ch::Plugin::Filter::DNSBL;
@@ -30,9 +30,7 @@ sub check_by_bbx {
     _check_proxy( 'bbx', @_ );
 }
 
-sub check_by_dsbl {
-    _check_proxy( 'dsbl', @_ );
-}
+sub check_by_dsbl {1}
 
 sub by_rbl {
     _check_proxy( 'rbl', @_ );
@@ -56,6 +54,10 @@ sub by_spamlookup {
     _check_proxy( 'spamlookup', @_ );
 }
 
+sub by_livedoor {
+    _check_proxy( 'livedoor', @_ );
+}
+
 sub _check_proxy {
     my ( $base, $iApp ) = @_;
     my $ip = $iApp->get_ip_int();
