@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007-2009 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Install.pm 1826 2009-04-08 15:23:25Z hikarin $
+# $Id: Install.pm 1976 2010-01-23 15:50:07Z hikarin $
 #
 
 package Img0ch::Plugin::Install;
@@ -106,13 +106,12 @@ sub install {
             methods => {
                 check_by_bbq  => 'bbs.filter',
                 check_by_bbx  => 'bbs.filter',
-                check_by_dsbl => 'bbs.filter',
                 by_rbl        => 'bbs.filter',
                 by_spamcop    => 'bbs.filter',
                 by_spamhaus   => 'bbs.filter',
-                by_blitzed    => 'bbs.filter',
                 by_empty      => 'bbs.filter',
                 by_spamlookup => 'bbs.filter',
+                by_livedoor   => 'bbs.filter',
             },
         }
     );
@@ -131,12 +130,6 @@ sub install {
             methods => { check => 'bbs.filter', },
         }
     );
-
-    #    $zPlugin->install(
-    #        {   package => 'Img0ch::Plugin::Filter::NGWord',
-    #            methods => { check => 'bbs.filter', },
-    #        }
-    #    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Filter::NGWord2',
             methods => { check => 'bbs.filter', },
@@ -152,6 +145,11 @@ sub install {
             methods => { check => 'bbs.filter', },
         }
     );
+    $zPlugin->install(
+        {   package => 'Img0ch::Plugin::Filter::URLWhiteList',
+            methods => { check => 'bbs.filter', },
+        }
+    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Filter::UnNaturalLink',
             methods => { check => 'bbs.filter', },
@@ -189,14 +187,6 @@ sub install {
             },
         }
     );
-    $zPlugin->install(
-        {   package => 'Img0ch::Plugin::Rewrite::StreamService::EbiTV',
-            methods => {
-                from_bbs  => 'bbs.rewrite',
-                from_read => 'read.rewrite',
-            },
-        }
-    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::FlipClip',
             methods => {
@@ -205,14 +195,6 @@ sub install {
             },
         }
     );
-    $zPlugin->install(
-        {   package => 'Img0ch::Plugin::Rewrite::StreamService::GoogleVideo',
-            methods => {
-                from_bbs  => 'bbs.rewrite',
-                from_read => 'read.rewrite',
-            },
-        }
-    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Rewrite::StreamService::NicoVideo',
             methods => {
@@ -263,11 +245,6 @@ sub install {
             methods => { check => 'bbs.upload.pre', },
         }
     );
-    $zPlugin->install(
-        {   package => 'Img0ch::Plugin::Upload::NoNude',
-            methods => { check => 'bbs.upload.post', },
-        }
-    );
     $zPlugin->install(
         {   package => 'Img0ch::Plugin::Upload::Note',
             methods => {
@@ -289,6 +266,52 @@ sub install {
         {   package => 'Img0ch::Plugin::Upload::XCSV',
             methods => {
                 repair   => 'zeromin.repair.upload',
+            },
+        }
+    );
+    return 1;
+}
+
+sub uninstall {
+    my ($zPlugin) = @_;
+
+    $zPlugin->uninstall(
+        {   package => 'Img0ch::Plugin::Filter::DNSBL',
+            methods => {
+                by_dsbl    => 'bbs.filter',
+                by_blitzed => 'bbs.filter',
+            },
+        }
+    );
+    $zPlugin->uninstall(
+        {   package => 'Img0ch::Plugin::Filter::NGWord',
+            methods => { check => 'bbs.filter', },
+        }
+    );
+    $zPlugin->uninstall(
+        {   package => 'Img0ch::Plugin::Rewrite::StreamService::EbiTV',
+            methods => {
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
+            },
+        }
+    );
+    $zPlugin->uninstall(
+        {   package => 'Img0ch::Plugin::Rewrite::StreamService::GoogleVideo',
+            methods => {
+                from_bbs  => 'bbs.rewrite',
+                from_read => 'read.rewrite',
+            },
+        }
+    );
+    $zPlugin->uninstall(
+        {   package => 'Img0ch::Plugin::Upload::NoNude',
+            methods => { check => 'bbs.upload.post', },
+        }
+    );
+    $zPlugin->uninstall(
+        {   package => 'Img0ch::Plugin::Upload::XCSV',
+            methods => {
                 generate => 'bbs.upload.post',
             },
         }
@@ -296,5 +319,3 @@ sub install {
     return 1;
 }
 
-1;
-__END__
