@@ -1,5 +1,5 @@
 #/*
-# *  Copyright 2007 hkrn <hikarin@users.sourceforge.jp>
+# *  Copyright 2007-2010 hkrn <hikarin@users.sourceforge.jp>
 # *
 # *  Licensed under the Apache License, Version 2.0 (the "License");
 # *  you may not use this file except in compliance with the License.
@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: BBS.pm 1437 2007-10-19 13:29:13Z hikarin $
+# $Id: BBS.pm 1901 2009-12-31 02:40:20Z hikarin $
 #
 
 package Zeromin::BBS;
@@ -54,12 +54,15 @@ sub create {
     my $rebuild = exists $hash->{__rebuild} ? 1 : 0;
 
     my $id = $zBBS->get_id();
+    my $utf8 = $hash->{utf8} ? 1 : 0;
     if ( !$rebuild ) {
         $id = $iRepos->get_int('I:B._') + 1;
         $iRepos->set( "I:B.c.${id}", ( $hash->{category} || 1 ) );
-        $iRepos->set( "I:B.d.${bbs}", $id );
-        $iRepos->set( "I:B.i.${id}",  $bbs );
-        $iRepos->set( 'I:B._',        $id );
+        $iRepos->set( "I:B.d.${bbs}",      $id );
+        $iRepos->set( "I:B.i.${id}",       $bbs );
+        $iRepos->set( "I:B.d.${bbs}.utf8", $utf8 );
+        $iRepos->set( "I:B.i.${id}.utf8",  $utf8 );
+        $iRepos->set( 'I:B._',             $id );
         $zBBS->{_id}     = $id;
         $zBBS->{_system} = $iKernel->get_repos(
             $iKernel->get_repos_path("${bbs}/system") ),;
@@ -117,21 +120,30 @@ sub create {
 
         $fh = $iKernel->get_read_file_handle($head);
         $zMeta->head(
-            \do { local $/ = undef; <$fh> }
+            \$iKernel->get_encoded_str(
+                do { local $/ = undef; <$fh> },
+                'utf8', 'sjis'
+            )
         );
         close $fh or $iKernel->throw_io_exception($head);
 
         my $meta = join '/', $init, 'default_fot.txt';
         $fh = $iKernel->get_read_file_handle($meta);
         $zMeta->foot(
-            \do { local $/ = undef; <$fh> }
+            \$iKernel->get_encoded_str(
+                do { local $/ = undef; <$fh> },
+                'utf8', 'sjis'
+            )
         );
         close $fh or $iKernel->throw_io_exception($meta);
 
         my $t_end = join '/', $static, '1000.txt';
         $fh = $iKernel->get_read_file_handle($t_end);
         $zMeta->thread_end(
-            \do { local $/ = undef; <$fh> }
+            \$iKernel->get_encoded_str(
+                do { local $/ = undef; <$fh> },
+                'utf8', 'sjis'
+            )
         );
         close $fh or $iKernel->throw_io_exception($t_end);
     }
@@ -142,9 +154,7 @@ sub create {
         $zSetting->set( $key, $zSetting->get_default($key) );
     }
 
-    $zSetting->set( 'BBS_BG_PICTURE',      "../${bbs}/ba.gif" );
-    $zSetting->set( 'BBS_TITLE_PICTURE',   "../${bbs}/kanban.gif" );
-    $zSetting->set( 'BBS_REFERER_CUSHION', 'ime.nu/' );
+    $zSetting->set( 'BBS_BG_PICTURE', "../${bbs}/ba.gif" );
 
     if ( my $inherit = $hash->{inherit} ) {
         my $iBBSInherit = Img0ch::BBS->new( $iKernel, { id => $inherit } );
@@ -158,10 +168,17 @@ sub create {
     $zSetting->set( 'BBS_SUBTITLE', $hash->{sub_title} );
     $zSetting->set( 'BBS_READONLY', 'on' );
     $zSetting->set( 'BBS_MODE', $hash->{uploadable} ? 'picture' : 'none' );
+    $utf8 and $zSetting->set( 'BBS_TEMPLATE', 'default_utf8' );
     $zSetting->save();
 
     my $iSubject = $zBBS->get_subject_instance();
     $iSubject->save("${path}/subject.txt");
+
+    $iRepos->load();
+    $iRepos->set( "I:B.c.${id}", ( $hash->{category} || 1 ) );
+    $iRepos->set( "I:B.d.${bbs}", $id );
+    $iRepos->set( "I:B.i.${id}",  $bbs );
+    $iRepos->set( 'I:B._',        $id );
     $iRepos->save();
 
     my $iRequest = $hash->{request};
@@ -359,20 +376,22 @@ REPAIR:
         -r $setting or next REPAIR;
         my $setting_hash = {};
 
-        my $fh = $iKernel->get_read_file_handle($setting);
+        my $iBBSNew = Zeromin::BBS->new( $iKernel, { bbs => $dir } );
+        my $fh      = $iKernel->get_read_file_handle($setting);
+        my $from    = $iBBSNew->get_encoding();
 
     SETTING:
         while ( my $line = <$fh> ) {
             chomp $line;
             $line =~ /\A(\w+)=(.+)\z/xms or next SETTING;
             my ( $key, $value ) = ( $1, $2 );
-            $setting_hash->{$key} = $value;
+            $setting_hash->{$key}
+                = $iKernel->get_encoded_str( $value, 'utf8', $from );
         }
         close $fh or $iKernel->throw_io_exception($setting);
 
-        my $iBBSNew = Zeromin::BBS->new( $iKernel, { bbs => $dir } );
         my $id = $iBBSNew->get_id();
-        if ( !$id ) {
+        if ( $iRepos->get("I:B.i.${id}") ne $dir ) {
             $iRepos->set( "I:B.d.${dir}",     ++$last_id );
             $iRepos->set( "I:B.i.${last_id}", $dir );
             $id              = $last_id;
@@ -393,21 +412,24 @@ REPAIR:
             my $head = join '/', $path, 'head.txt';
             if ( -r $head ) {
                 $fh = $iKernel->get_read_file_handle($head);
-                my $buffer = <$fh>;
+                my $buffer
+                    = $iKernel->get_encoded_str( <$fh>, 'utf8', $from );
                 close $fh or $iKernel->throw_io_exception($head);
                 $zMeta->head( \$buffer );
             }
             my $meta = join '/', $path, 'meta.txt';
             if ( -r $meta ) {
                 $fh = $iKernel->get_read_file_handle($meta);
-                my $buffer = <$fh>;
+                my $buffer
+                    = $iKernel->get_encoded_str( <$fh>, 'utf8', $from );
                 close $fh or $iKernel->throw_io_exception($meta);
                 $zMeta->meta( \$buffer );
             }
             my $foot = join '/', $path, 'foot.txt';
             if ( -r $foot ) {
                 $fh = $iKernel->get_read_file_handle($foot);
-                my $buffer = <$fh>;
+                my $buffer
+                    = $iKernel->get_encoded_str( <$fh>, 'utf8', $from );
                 close $fh or $iKernel->throw_io_exception($foot);
                 $zMeta->foot( \$buffer );
             }
@@ -540,8 +562,9 @@ sub get {
         my $category = $iRepos->get("I:B.c.${id}") || 1;
         my $cname    = $zCategory ? $zCategory->get_name($category) : '';
         if ($unijp) {
-            $name    = $unijp->set( $name,    'sjis' )->get();
-            $subname = $unijp->set( $subname, 'sjis' )->get();
+            my $charset = $iBBS->get_encoding();
+            $name    = $unijp->set( $name,    $charset )->get();
+            $subname = $unijp->set( $subname, $charset )->get();
         }
         {   id       => $id,
             name     => $name,
@@ -566,13 +589,14 @@ sub gets {
     my ( $zBBS, $bbs_ids, $unijp, $zCategory ) = @_;
     my $result = [];
     map { push @$result, $zBBS->get( $_, $unijp, $zCategory ) } @$bbs_ids;
+    @$result = grep { !$_->{id} } @$result;
     return $result;
 }
 
 sub gets_with_page {
     my ( $zBBS, $bbs_ids, $unijp, $zCategory, $item_per_page, $offset ) = @_;
 
-    require Data::Page;
+    defined $Data::Page::VERSION or require Data::Page;
     my $entries = $zBBS->gets( $bbs_ids, $unijp, $zCategory );
     my $page = Data::Page->new( scalar @$entries, $item_per_page, $offset );
     return ( [ $page->splice($entries) ], $page );
@@ -583,7 +607,9 @@ sub all {
     my $ret = [];
 
     for my $id ( @{ $zBBS->get_all_ids() } ) {
-        push @$ret, $zBBS->get( $id, $unijp, $zCategory );
+        my $data = $zBBS->get( $id, $unijp, $zCategory );
+        $data->{id} or next;
+        push @$ret, $data;
     }
 
     return $ret;
