@@ -14,7 +14,7 @@
 # *  limitations under the License.
 # */
 #
-# $Id: Action.pm 1960 2010-01-23 12:16:18Z hikarin $
+# $Id: Action.pm 1979 2010-01-25 14:19:36Z hikarin $
 #
 
 package Zeromin::Log::Action;
@@ -246,11 +246,11 @@ sub _retrive {
             $seen,
         );
         while ( my ( $prefix, $date ) = each %$seen ) {
-            my $user   = $iRepos->get("${prefix}.user");
-            my $class  = $iRepos->get("${prefix}.class");
-            my $ip     = $iRepos->get("${prefix}.ip");
+            my $user   = $iRepos->get("${prefix}.user") or next;
+            my $class  = $iRepos->get("${prefix}.class") or next;
+            my $ip     = $iRepos->get("${prefix}.ip") or next;
             my $ok     = $iRepos->get("${prefix}.ok");
-            my $reason = $iRepos->get("${prefix}.reason");
+            my $reason = $iRepos->get("${prefix}.reason") or next;
             my $param  = $iRepos->get("${prefix}.param");
             push @$ret,
                 {
